mizu package
============

Submodules
----------

mizu.mizu module
----------------

.. automodule:: mizu.mizu
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: mizu
   :members:
   :undoc-members:
   :show-inheritance:
